##  Step 2: Create Access Control Entities in SAP LeanIX
Configure access control entities in SAP LeanIX.
  1. Navigate to Administration > Access Control.
  2. Choose Add Entity.
  3. Enter an access control entity ID in uppercase letters with no space. Underscores are allowed.
Each attribute value must match the ace value configured in your IdP. For example, the access control value ID value FINANCE_DEPT matches the ace value FINANCE_DEPT.
![Configure access control entities for the ACLs in SAP LeanIX](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2757258f7a44101488b99e4ae899b719_LowRes.png)
  4. Enter a Display name.
For example: Finance
The display name is visible in SAP LeanIX when assigning access control entities manually.
  5. In the Description field, give more details as necessary to make the maintenance of access control entities easier in the future.
  6. Repeat to add more access control entities.
